[PATCH 1/1] drm: i915: don't use OpRegion for XPS 13 IvyBridge

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Skylake was already singled out, but it doesn't cover the XPS 13 L332X
model which is based on IvyBridge.

The commit that introduced the regression is
1d6da87a3241deb13d073c4125d19ed0e5a0c62c

The Skylake workaround for the regression was introduced in commit
aeddda06c1a704bb97c8a7bfe7a472120193bd56

Signed-off-by: Andrea Arcangeli <aarcange@xxxxxxxxxx>
---
 drivers/gpu/drm/i915/intel_opregion.c | 12 +++++++-----
 1 file changed, 7 insertions(+), 5 deletions(-)

diff --git a/drivers/gpu/drm/i915/intel_opregion.c b/drivers/gpu/drm/i915/intel_opregion.c
index adca262..ca17ab6 100644
--- a/drivers/gpu/drm/i915/intel_opregion.c
+++ b/drivers/gpu/drm/i915/intel_opregion.c
@@ -1073,12 +1073,14 @@ intel_opregion_get_panel_type(struct drm_i915_private *dev_priv)
 	}
 
 	/*
 	 * FIXME On Dell XPS 13 9350 the OpRegion panel type (0) gives us
 	 * low vswing for eDP, whereas the VBT panel type (2) gives us normal
 	 * vswing instead. Low vswing results in some display flickers, so
 	 * let's simply ignore the OpRegion panel type on SKL for now.
 	 */
-	if (IS_SKYLAKE(dev_priv)) {
+	if (IS_SKYLAKE(dev_priv) || IS_IVYBRIDGE(dev_priv)) {
 		DRM_DEBUG_KMS("Ignoring OpRegion panel type (%d)\n", ret - 1);
 		return -ENODEV;
 	}
@@ -1073,12 +1073,14 @@ intel_opregion_get_panel_type(struct drm_i915_private *dev_priv)
 
 	/*
-	 * FIXME On Dell XPS 13 9350 the OpRegion panel type (0) gives us
-	 * low vswing for eDP, whereas the VBT panel type (2) gives us normal
-	 * vswing instead. Low vswing results in some display flickers, so
-	 * let's simply ignore the OpRegion panel type on SKL for now.
+	 * FIXME On Dell XPS 13 9350 and Dell XPS 13 L322X the
+	 * OpRegion panel type (0) gives us low vswing for eDP,
+	 * whereas the VBT panel type (2) gives us normal vswing
+	 * instead. Low vswing results in some display flickers, so
+	 * let's simply ignore the OpRegion panel type on SKL and
+	 * IVYBRIDGE for now.
 	 */
_______________________________________________
dri-devel mailing list
dri-devel@xxxxxxxxxxxxxxxxxxxxx
https://lists.freedesktop.org/mailman/listinfo/dri-devel




[Index of Archives]     [Linux DRI Users]     [Linux Intel Graphics]     [Linux USB Devel]     [Video for Linux]     [Linux Audio Users]     [Yosemite News]     [Linux Kernel]     [Linux SCSI]     [XFree86]     [Linux USB Devel]     [Video for Linux]     [Linux Audio Users]     [Linux Kernel]     [Linux SCSI]     [XFree86]
  Powered by Linux